@@ -303,9 +303,9 @@ END
 
    DETAILS  => 'Nnar',
 
-   ALL_OFF => 'Virkja allar',
+   ALL_ON => 'Virkja allar',
 
-   ALL_ON  => 'Afvirkja allar',
+   ALL_OFF  => 'Afvirkja allar',
 
    ANALYSIS  => 'Greining',
 
